@@ -4,9 +4,9 @@ from selenium import webdriver
 import re
 
 
-def get_decisions(year, init_no=0, last_no=999999, keyword='içtihat'):
+def get_decisions(path, year, init_no=0, last_no=999999, keyword='içtihat'):
     # path of chromedriver.exe
-    driver_path = "../../chromedriver"
+    driver_path = path
 
     # define driver
     driver = webdriver.Chrome(executable_path=driver_path)
@@ -99,4 +99,4 @@ def get_decisions(year, init_no=0, last_no=999999, keyword='içtihat'):
         # go to next decision
         time.sleep(3)
         next_btn = driver.find_element_by_id('aramaForm:sonrakiEvrakLabel')
-        next_btn.click()
\ No newline at end of file
+        next_btn.click()
